<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 6/3/2009
// Revised: 1/13/2012	ELL
// Added deletion of draft copies as well.
// Revised: 2/8/2012	ELL
// Added table prefix handling.

	include ("check_session.php");
		
	$area_name = $_REQUEST['area_name'];
	
	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '". $area_name . "'";
	$cnt = $bwb_dbh->exec($query);
	
	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name = '". $area_name . "' AND `source`=1";
	$cnt = $bwb_dbh->exec($query);
	
	header("Location: manage_special.php");
?>